# Function 9 This function is not used by FLS5. Make two CVT values equal up to a specified ppm. Arguments on stack: _cvt_child, cvt_parent, max_ppm_

Assembly |  | Stack
--- | --- | ---
PUSHW[ ] | 1 value pushed
9 | function index
FDEF[ ] | FunctionDefinition
MPPEM[ ] | MeasurePixelPerEm | cvt_child cvt_parent max_ppm ppm
GTEQ[ ] | GreaterThanOrEqual | cvt_child cvt_parent max_ppm>=ppm
IF[ ] | If | cvt_child cvt_parent
RCVT[ ] | ReadCVT | cvt_child parent
WCVTP[ ] | WriteCVTInPixels | —
ELSE[ ] | Else | cvt_child cvt_parent
POP[ ] | PopTopStack | cvt_child
POP[ ] | PopTopStack | —
EIF[ ] | EndIf
ENDF[ ] | EndFunctionDefinition